<?php

/**
 * @file
 * Contains \Drupal\pagerer\PagererFactory.
 */

namespace Drupal\pagerer;

use Drupal\pagerer\Pagerer;

/**
 * Provides a factory for Pagerer pagers.
 */
class PagererFactory {

  /**
   * The array of pager objects.
   *
   * @var \Drupal\pagerer\Pagerer[]
   */
  protected $pagers = array();

  /**
   * Initialises the pagers.
   */
  public function initPagers() {
    global $pager_total;
    if (!empty($pager_total)) {
      for ($i = 0; $i <= max(array_keys($pager_total)); $i++) {
        $this->get($i);
      }
    }
  }

  /**
   * Returns the pager object for the specified pager element.
   *
   * @param int $element
   *   The pager element.
   *
   * @return \Drupal\pagerer\Pagerer
   *   The pager object.
   */
  public function get($element) {
    if (!isset($this->pagers[$element])) {
      // Fill any gap in the sequence.
      for ($i = max(count($this->pagers) - 1, 0); $i < $element; $i++) {
        $this->get($i);
      }
      $this->pagers[$element] = Pagerer::create(\Drupal::getContainer(), $element);
    }
    return $this->pagers[$element];
  }

  /**
   * Returns the array of pager objects.
   *
   * @return \Drupal\pagerer\Pagerer[]
   *   The array of pager objects.
   */
  public function all() {
    return $this->pagers;
  }

}
